cheesecake.logger.Producer

Package cheesecake :: Module logger :: Class Producer |
[show private | hide private]
[frames | no frames]

## Type Producer

    object --+
             |
            Producer

Known Subclasses:
  `MultipleProducer`

Log producer API which sends messages to be logged to a 'consumer' object, which then prints them to stdout, stderr, files, etc.

Method Summary
| `__init__(self, keywords)`
| `__call__(self, *args)`
| `__getattr__(self, name)`
| `__repr__(self)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Class Variable Summary
`dict` | `keywords2consumer` = `{'default': <function default_consum...`
`type` | `Message` = `cheesecake.logger.Message`

Class Variable Details

    ### keywords2consumer Type: `dict` Value:
        {'default': <function default_consumer at 0xb7b12df4>}

Generated by Epydoc 2.1 on Fri Feb 9 02:15:12 2007 | http://epydoc.sf.net